import { Configuration, BrowserAuthOptions, CacheOptions, BrowserSystemOptions, BrowserTelemetryOptions } from '@azure/msal-browser';
import { UserClaims } from 'unw.react.framework.user.identity';
import React$1, { PropsWithChildren } from 'react';

/**
 * Declare IAuthenticationProvider interface
 * Authentication provider component. This must be used other components.
 *
 * @field {auth} - use this to configure the auth options in the Configuration object
 * @field {cache} -  use this to configure the below cache configuration options
 * @field {system} -  use this to configure the below enable browser options
 * @field {telemetry} -  telemetry information sent on request appName and appVersion
*/
interface IAuthenticationInstance extends Configuration {
    auth: BrowserAuthOptions;
    cache?: CacheOptions;
    system?: BrowserSystemOptions;
    telemetry?: BrowserTelemetryOptions;
}

/**
 * Declare IAuthenticationConfiguration interface
 * This will hold the azure ad configuration
 *
 * @field {instance} - azure ad configuration
 * @field {option} -  external configuration
*/
interface IAuthenticationConfiguration {
    instance: IAuthenticationInstance;
    option: IExtentConfiguration;
}
/**
 * Declare IExtentConfiguration interface
 * This will hold the external configuration
 *
 * @field {scopes} - scopes of the azure ad request
 * @field {tokenInterval} -  token refresh interval in milliseconds
 * @field {tokenThreshold} -  token refresh before expiry in milliseconds
*/
interface IExtentConfiguration {
    scopes: string[];
    tokenInterval: number;
    tokenThreshold: number;
}

/**
 * Declare IMsalAuthentication interface
 *
 * @method {loginRedirect} - login and redirect to page
 * @method {loginPopup} - login popup with in the page
 * @method {logoutRedirect} - logout and redirect to page
 * @method {logoutPopup} - logout popup with in the page
 */
interface IMsalAuthentication {
    loginRedirect: () => void;
    loginPopup: () => void;
    logoutRedirect: () => void;
    logoutPopup: () => void;
}

/**
 * Declare IUseUserAccount interface
 *
 * @method {getUserToken} - get login user token
 * @method {getServiceApiAccessToken} - get and set access token to store
 * @method {setUserActiveAccount} - set user active account
 * @method {setClaims} - set claims to to store
 */
interface IUseUserAccount {
    getUserToken(): Promise<string | null | undefined>;
    getServiceApiAccessToken(key: string): Promise<string | null | undefined>;
    setUserActiveAccount(): Promise<void>;
    setClaims(userClaims: UserClaims[]): Promise<void>;
}

/**
 * Declare IAuthenticationProvider interface
 * Authentication provider component. This must be used other components.
 *
 * @field {authConfig} - authentication config
 * @field {beforeAuthComponent} -  component to redender before authenticate
*/
interface IAuthenticationProvider extends PropsWithChildren {
    authConfig?: IAuthenticationConfiguration;
    beforeAuthComponent?: React.ReactElement | undefined;
}

/**
* Authentication provider component. This must be rendered above any other components that use authentication

* @param children - children components to render after authenticated
* @param beforeAuthComponent - component to render before authenticated
* @param authConfig - azure ad authentication configuration
*/
declare const AuthenticationProvider: React$1.FC<IAuthenticationProvider>;

/**
 * This hooks to provide the types of login and logout functions
 *
 * @return {IMsalAuthentication} - returns authentication functions
 */
declare const useMsalAuthentication: () => IMsalAuthentication;

/**
 * This hooks used to get user token and set token to the store
 *
 * @return {IUseUserAccount} - returns get user token and set token to store functions
 */
declare const useUserAccount: () => IUseUserAccount;

/**
 * Check whether or not a user is currently signed in.
 *
 * @return {boolean} - returns true if a user is signed in otherwise return false
*/
declare const useAuthenticated: () => boolean;

export { AuthenticationProvider, type IAuthenticationConfiguration, type IMsalAuthentication, type IUseUserAccount, useUserAccount as useAccount, useAuthenticated, useMsalAuthentication as useAuthentication };
