// src/AuthenticationProvider.tsx
import React2 from "react";
import { InteractionType } from "@azure/msal-browser";
import { AuthenticatedTemplate, MsalAuthenticationTemplate, MsalProvider, UnauthenticatedTemplate } from "@azure/msal-react";

// src/hooks/useConfiguration.ts
import { useEffect, useState } from "react";

// src/helper/index.ts
var getEnvironmentValue = (key, isRequired = false) => {
  const envKey = process.env[`VITE_${key}`];
  if (envKey === void 0 || envKey === null && isRequired) {
    throw new Error(`VITE_${key} is not exists in the .env file`);
  }
  return envKey;
};
var Constants = {
  SPLIT_COMMA: ",",
  DEFAULT_TOKEN_INTERVAL: "3600000",
  DEFAULT_TOKEN_THRESHOLD: "300",
  DEFAULT_SCOPES: ["User.Read"],
  MIDDLEWARE_URL: "_MIDDLEWARE_URL",
  MIDDLEWARE_KEY: "_MIDDLEWARE_KEY",
  CLIENT_ID: "MSAL_CLIENT_ID",
  AUTHORITY: "MSAL_AUTHORITY",
  REDIRECT_URL: "MSAL_REDIRECT_URL",
  LOGOUT_REDIRECT_URL: "MSAL_LOGOUT_REDIRECT_URL",
  SCOPES: "MSAL_SCOPES",
  CACHE_LOCATION: "MSAL_CACHE_LOCATION",
  TOKEN_INTERVAL: "MSAL_TOKEN_INTERVAL",
  TOKEN_REFRESH_THRESHOLD: "MSAL_TOKEN_REFRESH_THRESHOLD"
};

// src/AuthenticationInstance.ts
import { BrowserCacheLocation, PublicClientApplication } from "@azure/msal-browser";
var AuthenticationInstance = class {
  /**
   * PublicClientApplication property
   */
  PublicClientApplication;
  /**
   * Overload constructor function
   */
  constructor(instance) {
    if (instance === void 0 || instance === null) {
      instance = {
        auth: {
          clientId: getEnvironmentValue(Constants.CLIENT_ID, true),
          authority: getEnvironmentValue(Constants.AUTHORITY, true),
          redirectUri: getEnvironmentValue(Constants.REDIRECT_URL, true),
          postLogoutRedirectUri: getEnvironmentValue(Constants.LOGOUT_REDIRECT_URL)
        },
        cache: {
          cacheLocation: getEnvironmentValue(Constants.CACHE_LOCATION) || BrowserCacheLocation.LocalStorage,
          storeAuthStateInCookie: true
        },
        system: {
          tokenRenewalOffsetSeconds: parseInt(getEnvironmentValue(Constants.TOKEN_REFRESH_THRESHOLD) || Constants.DEFAULT_TOKEN_THRESHOLD)
        }
      };
    }
    this.PublicClientApplication = new PublicClientApplication(instance);
  }
};

// src/hooks/useConfiguration.ts
var useConfiguration = (authConfig) => {
  const [instance, setInstance] = useState();
  const [options, setOptions] = useState();
  useEffect(() => {
    setConfiguration(authConfig);
  }, [authConfig]);
  const setConfiguration = (authConfig2) => {
    const msalInstance = new AuthenticationInstance(authConfig2?.instance);
    let option;
    if (authConfig2 != null && authConfig2.option) {
      option = authConfig2.option;
    } else {
      option = {
        scopes: [getEnvironmentValue(Constants.SCOPES, true)],
        tokenInterval: parseInt(getEnvironmentValue(Constants.TOKEN_INTERVAL) || Constants.DEFAULT_TOKEN_INTERVAL),
        tokenThreshold: parseInt(getEnvironmentValue(Constants.TOKEN_REFRESH_THRESHOLD) || Constants.DEFAULT_TOKEN_THRESHOLD)
      };
    }
    setOptions(option);
    setInstance(msalInstance.PublicClientApplication);
  };
  return { config: instance, option: options };
};
var useConfiguration_default = useConfiguration;

// src/components/AuthenticationSuccess.tsx
import React, { useEffect as useEffect2 } from "react";

// src/hooks/useUserAccount.ts
import { useContext } from "react";
import { useMsal } from "@azure/msal-react";
import { InteractionRequiredAuthError } from "@azure/msal-browser";
import { jwtDecode } from "jwt-decode";
import { useUserClaimService, useUserTokenService, useUserService, useAPITokenService } from "unw.react.framework.user.identity";

// src/AuthenticationContext.ts
import { createContext } from "react";
var AuthenticationContext = createContext(null);

// src/hooks/useUserAccount.ts
var useUserAccount = () => {
  const { instance, accounts } = useMsal();
  const authentication = useContext(AuthenticationContext);
  const { setUserToken, getTokenInfo } = useUserTokenService();
  const { getAPIServiceTokenInfo, setAPIServiceToken } = useAPITokenService();
  const { setUserClaims } = useUserClaimService();
  const { setUserInfo } = useUserService();
  const getUserToken = async () => {
    const token = getTokenInfo();
    if (token && !isTokenExpired(0, token)) {
      return token;
    }
    const accountInfo = await getAcquireTokenSilent();
    if (accountInfo) {
      setUserTokenToStore(accountInfo);
    }
    return accountInfo?.accessToken;
  };
  const getServiceApiAccessToken = async (key) => {
    const apiServiceToken = getAPIServiceTokenInfo(key);
    if (apiServiceToken && apiServiceToken != null) {
      if (!isTokenExpired(0, apiServiceToken.refreshToken)) {
        return apiServiceToken.refreshToken;
      } else if (!isTokenExpired(0, apiServiceToken.accessToken)) {
        return apiServiceToken.accessToken;
      }
    }
    const tokenInfo = await getApiTokenInfo(key);
    if (tokenInfo) {
      const sharePointToken = [
        {
          tokenId: key,
          refreshToken: tokenInfo.access_token,
          accessToken: tokenInfo.access_token,
          tokenExpirationDate: tokenInfo.expires_on.toLocaleString()
        }
      ];
      setAPIServiceToken(sharePointToken);
      return tokenInfo.access_token;
    }
    return null;
  };
  const getApiTokenInfo = async (key) => {
    const envKey = key.toUpperCase();
    const apiAccessUrl = getEnvironmentValue(envKey + Constants.MIDDLEWARE_URL);
    const middlewareKey = getEnvironmentValue(envKey + Constants.MIDDLEWARE_KEY);
    const response = await fetch(apiAccessUrl, {
      method: "GET",
      headers: {
        "X-Middleware-Key": middlewareKey
      }
    });
    return response.json();
  };
  const setClaims = async (userClaims) => {
    if (userClaims && userClaims.length > 0) {
      setUserClaims(userClaims);
    }
  };
  const getAcquireTokenSilent = async (scopes) => {
    const authRequest = { account: accounts[0], scopes: Constants.DEFAULT_SCOPES };
    if (scopes != null && scopes.length > 0) {
      authRequest.scopes = scopes;
    }
    try {
      const response = await instance.acquireTokenSilent(authRequest);
      return response;
    } catch (err) {
      if (err instanceof InteractionRequiredAuthError) {
        await instance.acquireTokenRedirect(authRequest);
      }
    }
  };
  const setAccountInfoToStore = (accountInfo) => {
    if (accountInfo) {
      setUserTokenToStore(accountInfo);
      setAccessTokenToStore(accountInfo);
    }
  };
  const setUserTokenToStore = (accountInfo) => {
    if (accountInfo) {
      const userToken = {
        tokenId: accountInfo.account?.localAccountId,
        idToken: accountInfo.account?.idToken,
        accessToken: accountInfo.accessToken,
        refreshToken: accountInfo.accessToken,
        tokenExpirationDate: accountInfo.expiresOn.toLocaleString()
      };
      setUserToken(userToken);
    }
  };
  const setAccessTokenToStore = (accountInfo) => {
    const accessToken = accountInfo.accessToken;
    if (accessToken) {
      const decodeToken = jwtDecode(accessToken);
      if (decodeToken) {
        const user = {
          name: decodeToken.name,
          firstname: decodeToken.given_name,
          lastName: decodeToken.family_name,
          email: accountInfo.username,
          upn: decodeToken.upn,
          guid: decodeToken.oid
        };
        setUserInfo(user);
      }
    }
  };
  const setAcquireTokenToStore = async () => {
    const scopes = authentication?.option?.scopes;
    const accountInfo = await getAcquireTokenSilent(scopes);
    if (accountInfo) {
      setAccountInfoToStore(accountInfo);
    }
  };
  const setUserActiveAccount = async () => {
    const currentAccounts = instance.getAllAccounts();
    if (currentAccounts.length > 0) {
      instance.setActiveAccount(currentAccounts[0]);
    }
    await setAcquireTokenToStore();
    setRefreshTokenInterval();
  };
  const setRefreshTokenInterval = () => {
    const option = authentication?.option;
    if (option) {
      const threshold = option.tokenThreshold;
      const interval = option.tokenInterval;
      setInterval(() => {
        const token = getTokenInfo();
        if (token === void 0 || isTokenExpired(threshold, token)) {
          setAcquireTokenToStore();
        }
      }, interval);
    }
  };
  const isTokenExpired = (tokenThreshold, token) => {
    let isExpired = false;
    if (token && token != null) {
      const decodeToken = jwtDecode(token);
      if (decodeToken.exp) {
        const currentTime = Math.floor(Date.now() / 1e3);
        const timeUntilExpiry = decodeToken.exp - currentTime;
        isExpired = timeUntilExpiry <= (tokenThreshold ?? 0);
      }
    }
    return isExpired;
  };
  return { getUserToken, getServiceApiAccessToken, setUserActiveAccount, setClaims };
};
var useUserAccount_default = useUserAccount;

// src/components/AuthenticationSuccess.tsx
var AuthenticationSuccess = ({ children }) => {
  const { setUserActiveAccount } = useUserAccount_default();
  useEffect2(() => {
    setUserActiveAccount();
  }, []);
  return /* @__PURE__ */ React.createElement(React.Fragment, null, children);
};
var AuthenticationSuccess_default = AuthenticationSuccess;

// src/AuthenticationProvider.tsx
var AuthenticationProvider = ({ children, beforeAuthComponent, authConfig }) => {
  const { config, option } = useConfiguration_default(authConfig);
  return config != null ? /* @__PURE__ */ React2.createElement(AuthenticationContext.Provider, { value: { option } }, /* @__PURE__ */ React2.createElement(MsalProvider, { instance: config }, beforeAuthComponent ? /* @__PURE__ */ React2.createElement(React2.Fragment, null, /* @__PURE__ */ React2.createElement(UnauthenticatedTemplate, null, beforeAuthComponent), /* @__PURE__ */ React2.createElement(AuthenticatedTemplate, null, /* @__PURE__ */ React2.createElement(AuthenticationSuccess_default, null, children))) : /* @__PURE__ */ React2.createElement(React2.Fragment, null, /* @__PURE__ */ React2.createElement(MsalAuthenticationTemplate, { authenticationRequest: { scopes: option?.scopes }, interactionType: InteractionType.Redirect }, /* @__PURE__ */ React2.createElement(AuthenticationSuccess_default, null, children))))) : null;
};
var AuthenticationProvider_default = AuthenticationProvider;

// src/hooks/useMsalAuthentication.ts
import { useMsal as useMsal2 } from "@azure/msal-react";
var useMsalAuthentication = () => {
  const { instance } = useMsal2();
  const loginRedirect = () => {
    instance.loginRedirect().catch((error) => {
      throw new Error(error);
    });
  };
  const loginPopup = () => {
    instance.loginPopup().catch((error) => {
      throw new Error(error);
    });
  };
  const logoutRedirect = () => {
    instance.logoutRedirect().catch((error) => {
      throw new Error(error);
    });
  };
  const logoutPopup = () => {
    instance.logoutPopup({
      account: instance.getActiveAccount()
    }).catch((error) => {
      throw new Error(error);
    });
  };
  return { loginRedirect, loginPopup, logoutRedirect, logoutPopup };
};
var useMsalAuthentication_default = useMsalAuthentication;

// src/hooks/useAuthenticated.ts
import { useIsAuthenticated } from "@azure/msal-react";
var useAuthenticated = () => {
  const isAuthenticated = useIsAuthenticated();
  return isAuthenticated;
};
var useAuthenticated_default = useAuthenticated;
export {
  AuthenticationProvider_default as AuthenticationProvider,
  useUserAccount_default as useAccount,
  useAuthenticated_default as useAuthenticated,
  useMsalAuthentication_default as useAuthentication
};
